@@ -2,7 +2,7 @@
  * mmstu.h: MMS access plug-in
  *****************************************************************************
  * Copyright (C) 2001, 2002 VLC authors and VideoLAN
- * $Id: 5d75bb2b599fe1e771faecd217e74446c8257b92 $
+ * $Id: ee65939cba57138187eaa76d18441d463bb0bb15 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -43,6 +43,7 @@ struct access_sys_t
     char        sz_bind_addr[NI_MAXNUMERICHOST]; /* used by udp */
 
     vlc_url_t   url;
+    uint64_t    i_size;
 
     asf_header_t    asfh;
 
@@ -50,10 +51,10 @@ struct access_sys_t
 
     /* */
     uint8_t     buffer_tcp[MMS_BUFFER_SIZE];
-    int         i_buffer_tcp;
+    size_t      i_buffer_tcp;
 
     uint8_t     buffer_udp[MMS_BUFFER_SIZE];
-    int         i_buffer_udp;
+    size_t      i_buffer_udp;
 
     /* data necessary to send data to server */
     guid_t      guid;
@@ -88,7 +89,7 @@ struct access_sys_t
     uint32_t    i_media_length;
     size_t      i_packet_length;
     uint32_t    i_packet_count;
-    int         i_max_bit_rate;
+    uint32_t    i_max_bit_rate;
     size_t      i_header_size;
 
     /* misc */
