@@ -2,7 +2,7 @@
  * avi.c : AVI file Stream input module for vlc
  *****************************************************************************
  * Copyright (C) 2001-2009 VLC authors and VideoLAN
- * $Id: 76b55d0aca6d0263311513b83a30ed29923c25ce $
+ * $Id: c661c3ab8a584c85aaa086455e78087c5c414172 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -313,17 +313,17 @@ static int Open( vlc_object_t * p_this )
         return VLC_EGENERIC;
     }
 
-    if( AVI_ChunkCount( &p_sys->ck_root, AVIFOURCC_RIFF ) > 1 )
+    if( AVI_ChunkCount( &p_sys->ck_root, AVIFOURCC_RIFF, true ) > 1 )
     {
         unsigned int i_count =
-            AVI_ChunkCount( &p_sys->ck_root, AVIFOURCC_RIFF );
+            AVI_ChunkCount( &p_sys->ck_root, AVIFOURCC_RIFF, true );
 
         msg_Warn( p_demux, "multiple riff -> OpenDML ?" );
         for( i = 1; i < i_count; i++ )
         {
             avi_chunk_list_t *p_sysx;
 
-            p_sysx = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, i );
+            p_sysx = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, i, true );
             if( p_sysx->i_type == AVIFOURCC_AVIX )
             {
                 msg_Warn( p_demux, "detected OpenDML file" );
@@ -333,11 +333,11 @@ static int Open( vlc_object_t * p_this )
         }
     }
 
-    p_riff  = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0 );
-    p_hdrl  = AVI_ChunkFind( p_riff, AVIFOURCC_hdrl, 0 );
-    p_movi  = AVI_ChunkFind( p_riff, AVIFOURCC_movi, 0 );
+    p_riff  = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0, true );
+    p_hdrl  = AVI_ChunkFind( p_riff, AVIFOURCC_hdrl, 0, true );
+    p_movi  = AVI_ChunkFind( p_riff, AVIFOURCC_movi, 0, true );
     if( !p_movi )
-        p_movi  = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_movi, 0 );
+        p_movi  = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_movi, 0, true );
 
     if( !p_hdrl || !p_movi )
     {
@@ -345,12 +345,12 @@ static int Open( vlc_object_t * p_this )
         goto error;
     }
 
-    if( !( p_avih = AVI_ChunkFind( p_hdrl, AVIFOURCC_avih, 0 ) ) )
+    if( !( p_avih = AVI_ChunkFind( p_hdrl, AVIFOURCC_avih, 0, false ) ) )
     {
         msg_Err( p_demux, "invalid file: cannot find avih chunk" );
         goto error;
     }
-    i_track = AVI_ChunkCount( p_hdrl, AVIFOURCC_strl );
+    i_track = AVI_ChunkCount( p_hdrl, AVIFOURCC_strl, true );
     if( p_avih->i_streams != i_track )
     {
         msg_Warn( p_demux,
@@ -383,9 +383,9 @@ static int Open( vlc_object_t * p_this )
         if( unlikely( !tk ) )
             goto error;
 
-        avi_chunk_list_t      *p_strl = AVI_ChunkFind( p_hdrl, AVIFOURCC_strl, i );
-        avi_chunk_strh_t      *p_strh = AVI_ChunkFind( p_strl, AVIFOURCC_strh, 0 );
-        avi_chunk_STRING_t    *p_strn = AVI_ChunkFind( p_strl, AVIFOURCC_strn, 0 );
+        avi_chunk_list_t      *p_strl = AVI_ChunkFind( p_hdrl, AVIFOURCC_strl, i, true );
+        avi_chunk_strh_t      *p_strh = AVI_ChunkFind( p_strl, AVIFOURCC_strh, 0, false );
+        avi_chunk_STRING_t    *p_strn = AVI_ChunkFind( p_strl, AVIFOURCC_strn, 0, false );
         avi_chunk_strf_auds_t *p_auds = NULL;
         avi_chunk_strf_vids_t *p_vids = NULL;
         es_format_t fmt;
@@ -393,8 +393,8 @@ static int Open( vlc_object_t * p_this )
         tk->b_eof = false;
         tk->b_activated = true;
 
-        p_vids = (avi_chunk_strf_vids_t*)AVI_ChunkFind( p_strl, AVIFOURCC_strf, 0 );
-        p_auds = (avi_chunk_strf_auds_t*)AVI_ChunkFind( p_strl, AVIFOURCC_strf, 0 );
+        p_vids = (avi_chunk_strf_vids_t*)AVI_ChunkFind( p_strl, AVIFOURCC_strf, 0, false );
+        p_auds = (avi_chunk_strf_auds_t*)AVI_ChunkFind( p_strl, AVIFOURCC_strf, 0, false );
 
         if( p_strl == NULL || p_strh == NULL || p_auds == NULL || p_vids == NULL )
         {
@@ -459,11 +459,11 @@ static int Open( vlc_object_t * p_this )
                 fmt.audio.i_bitspersample   = p_auds->p_wf->wBitsPerSample;
                 fmt.b_packetized            = !tk->i_blocksize;
 
-                avi_chunk_list_t *p_info = AVI_ChunkFind( p_riff, AVIFOURCC_INFO, 0 );
+                avi_chunk_list_t *p_info = AVI_ChunkFind( p_riff, AVIFOURCC_INFO, 0, true );
                 if( p_info )
                 {
                     int i_chunk = AVIFOURCC_IAS1 + ((i - 1) << 24);
-                    avi_chunk_STRING_t *p_lang = AVI_ChunkFind( p_info, i_chunk, 0 );
+                    avi_chunk_STRING_t *p_lang = AVI_ChunkFind( p_info, i_chunk, 0, false );
                     if( p_lang != NULL && p_lang->p_str != NULL )
                         fmt.psz_language = FromACP( p_lang->p_str );
                 }
@@ -590,7 +590,7 @@ static int Open( vlc_object_t * p_this )
                     fmt.video.i_height =
                         (unsigned int)(-(int)p_vids->p_bih->biHeight);
 
-                avi_chunk_vprp_t *p_vprp = AVI_ChunkFind( p_strl, AVIFOURCC_vprp, 0 );
+                avi_chunk_vprp_t *p_vprp = AVI_ChunkFind( p_strl, AVIFOURCC_vprp, 0, false );
                 if( p_vprp )
                 {
                     uint32_t i_frame_aspect_ratio = p_vprp->i_frame_aspect_ratio;
@@ -774,8 +774,8 @@ aviindex:
         {
             continue;
         }
-        p_strl = AVI_ChunkFind( p_hdrl, AVIFOURCC_strl, i );
-        p_auds = AVI_ChunkFind( p_strl, AVIFOURCC_strf, 0 );
+        p_strl = AVI_ChunkFind( p_hdrl, AVIFOURCC_strl, i, true );
+        p_auds = AVI_ChunkFind( p_strl, AVIFOURCC_strf, 0, false );
 
         if( p_auds->p_wf->wFormatTag != WAVE_FORMAT_PCM &&
             (unsigned int)tk->i_rate == p_auds->p_wf->nSamplesPerSec )
@@ -1447,7 +1447,7 @@ static int Seek( demux_t *p_demux, mtime_t i_date, int i_percent )
         /* Check and lazy load indexes if it was not done (not fastseekable) */
         if ( !p_sys->b_indexloaded && ( p_sys->i_avih_flags & AVIF_HASINDEX ) )
         {
-            avi_chunk_t *p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0 );
+            avi_chunk_t *p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0, true );
             if (unlikely( !p_riff ))
                 return VLC_EGENERIC;
 
@@ -2295,8 +2295,8 @@ static int AVI_IndexFind_idx1( demux_t *p_demux,
 {
     demux_sys_t *p_sys = p_demux->p_sys;
 
-    avi_chunk_list_t *p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0);
-    avi_chunk_idx1_t *p_idx1 = AVI_ChunkFind( p_riff, AVIFOURCC_idx1, 0);
+    avi_chunk_list_t *p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0, true );
+    avi_chunk_idx1_t *p_idx1 = AVI_ChunkFind( p_riff, AVIFOURCC_idx1, 0, false );
 
     if( !p_idx1 )
     {
@@ -2310,7 +2310,7 @@ static int AVI_IndexFind_idx1( demux_t *p_demux,
      * checking the offset of the first packet is not enough as some files
      * has unused chunk at the beginning of the movi content.
      */
-    avi_chunk_list_t *p_movi = AVI_ChunkFind( p_riff, AVIFOURCC_movi, 0);
+    avi_chunk_list_t *p_movi = AVI_ChunkFind( p_riff, AVIFOURCC_movi, 0, true );
     uint64_t i_first_pos = UINT64_MAX;
     for( unsigned i = 0; i < __MIN( p_idx1->i_entry_count, 100 ); i++ )
     {
@@ -2425,8 +2425,8 @@ static void AVI_IndexLoad_indx( demux_t *p_demux,
     avi_chunk_list_t    *p_riff;
     avi_chunk_list_t    *p_hdrl;
 
-    p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0);
-    p_hdrl = AVI_ChunkFind( p_riff, AVIFOURCC_hdrl, 0 );
+    p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0, true );
+    p_hdrl = AVI_ChunkFind( p_riff, AVIFOURCC_hdrl, 0, true );
 
     for( unsigned i_stream = 0; i_stream < p_sys->i_track; i_stream++ )
     {
@@ -2434,8 +2434,8 @@ static void AVI_IndexLoad_indx( demux_t *p_demux,
         avi_chunk_indx_t    *p_indx;
 
 #define p_stream  p_sys->track[i_stream]
-        p_strl = AVI_ChunkFind( p_hdrl, AVIFOURCC_strl, i_stream );
-        p_indx = AVI_ChunkFind( p_strl, AVIFOURCC_indx, 0 );
+        p_strl = AVI_ChunkFind( p_hdrl, AVIFOURCC_strl, i_stream, true );
+        p_indx = AVI_ChunkFind( p_strl, AVIFOURCC_indx, 0, false );
 
         if( !p_indx )
         {
@@ -2546,8 +2546,8 @@ static void AVI_IndexCreate( demux_t *p_demux )
     mtime_t i_dialog_update;
     dialog_progress_bar_t *p_dialog = NULL;
 
-    p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0);
-    p_movi = AVI_ChunkFind( p_riff, AVIFOURCC_movi, 0);
+    p_riff = AVI_ChunkFind( &p_sys->ck_root, AVIFOURCC_RIFF, 0, true );
+    p_movi = AVI_ChunkFind( p_riff, AVIFOURCC_movi, 0, true );
 
     if( !p_movi )
     {
@@ -2617,7 +2617,7 @@ static void AVI_IndexCreate( demux_t *p_demux )
                 {
                     avi_chunk_list_t *p_sysx;
                     p_sysx = AVI_ChunkFind( &p_sys->ck_root,
-                                            AVIFOURCC_RIFF, 1 );
+                                            AVIFOURCC_RIFF, 1, true );
 
                     msg_Dbg( p_demux, "looking for new RIFF chunk" );
                     if( stream_Seek( p_demux->s, p_sysx->i_chunk_pos + 24 ) )
@@ -2680,7 +2680,7 @@ static void AVI_MetaLoad( demux_t *p_demux,
               p_avih->i_flags&AVIF_TRUSTCKTYPE   ? " TRUST_CKTYPE"   : "" );
     vlc_meta_SetSetting( p_meta, buffer );
 
-    avi_chunk_list_t *p_info = AVI_ChunkFind( p_riff, AVIFOURCC_INFO, 0 );
+    avi_chunk_list_t *p_info = AVI_ChunkFind( p_riff, AVIFOURCC_INFO, 0, true );
     if( !p_info )
         return;
 
@@ -2703,7 +2703,7 @@ static void AVI_MetaLoad( demux_t *p_demux,
     };
     for( int i = 0; p_dsc[i].i_id != 0; i++ )
     {
-        avi_chunk_STRING_t *p_strz = AVI_ChunkFind( p_info, p_dsc[i].i_id, 0 );
+        avi_chunk_STRING_t *p_strz = AVI_ChunkFind( p_info, p_dsc[i].i_id, 0, false );
         if( !p_strz || !p_strz->p_str )
             continue;
         char *psz_value = FromACP( p_strz->p_str );
@@ -2727,7 +2727,7 @@ static void AVI_MetaLoad( demux_t *p_demux,
 
     for( int i = 0; p_extra[i] != 0; i++ )
     {
-        avi_chunk_STRING_t *p_strz = AVI_ChunkFind( p_info, p_extra[i], 0 );
+        avi_chunk_STRING_t *p_strz = AVI_ChunkFind( p_info, p_extra[i], 0, false );
         if( !p_strz || !p_strz->p_str )
             continue;
         char *psz_value = FromACP( p_strz->p_str );
@@ -2785,7 +2785,7 @@ static void AVI_ExtractSubtitle( demux_t *p_demux,
     if( !p_sys->b_seekable )
         goto exit;
 
-    p_indx = AVI_ChunkFind( p_strl, AVIFOURCC_indx, 0 );
+    p_indx = AVI_ChunkFind( p_strl, AVIFOURCC_indx, 0, false );
     avi_chunk_t ck;
     int64_t  i_position;
     unsigned i_size;
