@@ -2,7 +2,7 @@
  * libavi.h : LibAVI library
  ******************************************************************************
  * Copyright (C) 2001-2003 VLC authors and VideoLAN
- * $Id: 4ae9aa6579f0864ed5361fa4eb83d20609d08bbe $
+ * $Id: de7c127deefef81607cdc97394d5364e8ae8ed05 $
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -254,16 +254,17 @@ int     AVI_ChunkRead( stream_t *,
                        avi_chunk_t *p_father );
 void    AVI_ChunkFree( stream_t *, avi_chunk_t * );
 
-int     _AVI_ChunkCount( avi_chunk_t *, vlc_fourcc_t );
-void   *_AVI_ChunkFind ( avi_chunk_t *, vlc_fourcc_t, int );
+int     AVI_ChunkCount_( avi_chunk_t *, vlc_fourcc_t, bool );
+void   *AVI_ChunkFind_ ( avi_chunk_t *, vlc_fourcc_t, int, bool );
 
 int     AVI_ChunkReadRoot( stream_t *, avi_chunk_t *p_root );
 void    AVI_ChunkFreeRoot( stream_t *, avi_chunk_t *p_chk  );
+int     AVI_ChunkFetchIndexes( stream_t *, avi_chunk_t *p_riff );
 
-#define AVI_ChunkCount( p_chk, i_fourcc ) \
-    _AVI_ChunkCount( AVI_CHUNK(p_chk), i_fourcc )
-#define AVI_ChunkFind( p_chk, i_fourcc, i_number ) \
-    _AVI_ChunkFind( AVI_CHUNK(p_chk), i_fourcc, i_number )
+#define AVI_ChunkCount( p_chk, i_fourcc, b_list ) \
+    AVI_ChunkCount_( AVI_CHUNK(p_chk), i_fourcc, b_list )
+#define AVI_ChunkFind( p_chk, i_fourcc, i_number, b_list ) \
+    AVI_ChunkFind_( AVI_CHUNK(p_chk), i_fourcc, i_number, b_list )
 
 /* *** avi stuff *** */
 
@@ -343,6 +344,15 @@ void    AVI_ChunkFreeRoot( stream_t *, avi_chunk_t *p_chk  );
 #define AVIFOURCC_ISTR         VLC_FOURCC('I','S','T','R')
 #define AVIFOURCC_IFRM         VLC_FOURCC('I','F','R','M')
 
+#define AVIFOURCC_IAS1         VLC_FOURCC('I','A','S','1')
+#define AVIFOURCC_IAS2         VLC_FOURCC('I','A','S','2')
+#define AVIFOURCC_IAS3         VLC_FOURCC('I','A','S','3')
+#define AVIFOURCC_IAS4         VLC_FOURCC('I','A','S','4')
+#define AVIFOURCC_IAS5         VLC_FOURCC('I','A','S','5')
+#define AVIFOURCC_IAS6         VLC_FOURCC('I','A','S','6')
+#define AVIFOURCC_IAS7         VLC_FOURCC('I','A','S','7')
+#define AVIFOURCC_IAS8         VLC_FOURCC('I','A','S','8')
+#define AVIFOURCC_IAS9         VLC_FOURCC('I','A','S','9')
 
 #define AVITWOCC_wb            VLC_TWOCC('w','b')
 #define AVITWOCC_db            VLC_TWOCC('d','b')
