@@ -2,7 +2,7 @@
  * fspanel.m: MacOS X full screen panel
  *****************************************************************************
  * Copyright (C) 2006-2013 VLC authors and VideoLAN
- * $Id: e387ab3780666eab619e4f86b0024d974e62a434 $
+ * $Id: b58e9134a70faab4bebd039691b1a08e9bfc3084 $
  *
  * Authors: Jérôme Decoodt <djc at videolan dot org>
  *          Felix Paul Kühne <fkuehne at videolan dot org>
@@ -48,6 +48,11 @@
                     defer:(BOOL)flag
 {
     id win = [super initWithContentRect:contentRect styleMask:NSTexturedBackgroundWindowMask backing:bufferingType defer:flag];
+
+    if (!win)
+        return win;
+
+    self.contentView = [[VLCFSPanelView alloc] initWithFrame:contentRect];
     [win setOpaque:NO];
     [win setHasShadow: NO];
     [win setBackgroundColor:[NSColor clearColor]];
@@ -58,12 +63,9 @@
     [win setLevel:NSModalPanelWindowLevel];
     i_device = config_GetInt(VLCIntf, "macosx-vdev");
     hideAgainTimer = fadeTimer = nil;
+    [self setFrameAutosaveName:@"fspanel"];
     [self setNonActive:nil];
-    return win;
-}
 
-- (void)awakeFromNib
-{
     [self setContentView:[[VLCFSPanelView alloc] initWithFrame: [self frame]]];
     BOOL isInside = (NSPointInRect([NSEvent mouseLocation],[self frame]));
     [[self contentView] addTrackingRect:[[self contentView] bounds] owner:self userData:nil assumeInside:isInside];
@@ -77,18 +79,20 @@
 
     /* get a notification if VLC isn't the active app anymore */
     [[NSNotificationCenter defaultCenter]
-    addObserver: self
-       selector: @selector(setNonActive:)
-           name: NSApplicationDidResignActiveNotification
-         object: NSApp];
+     addObserver: self
+     selector: @selector(setNonActive:)
+     name: NSApplicationDidResignActiveNotification
+     object: NSApp];
 
     /* Get a notification if VLC is the active app again.
      Needed as becomeKeyWindow does not get called when window is activated by clicking */
     [[NSNotificationCenter defaultCenter]
-    addObserver: self
-       selector: @selector(setActive:)
-           name: NSApplicationDidBecomeActiveNotification
-         object: NSApp];
+     addObserver: self
+     selector: @selector(setActive:)
+     name: NSApplicationDidBecomeActiveNotification
+     object: NSApp];
+
+    return win;
 }
 
 /* make sure that we don't become key, since we can't handle hotkeys */
@@ -386,8 +390,8 @@
     [o_button setBezelStyle: NSRegularSquareBezelStyle];                                        \
     [o_button setBordered: NO];                                                                 \
     [o_button setFont:[NSFont systemFontOfSize:0]];                                             \
-    [o_button setImage:[NSImage imageNamed:imageOff]];                                 \
-    [o_button setAlternateImage:[NSImage imageNamed:imageOn]];                         \
+    [o_button setImage:imageFromRes(imageOff)];                                 \
+    [o_button setAlternateImage:imageFromRes(imageOn)];                         \
     [o_button sizeToFit];                                                                       \
     [o_button setTarget: self];                                                                 \
     [o_button setAction: @selector(action:)];                                                   \
@@ -482,11 +486,11 @@
     addTextfield(VLCTimeField, o_streamLength_txt, NSRightTextAlignment, systemFontOfSize, whiteColor);
     [o_streamLength_txt setRemainingIdentifier: @"DisplayFullscreenTimeAsTimeRemaining"];
 
-    o_background_img = [[NSImage imageNamed:@"fs_background"] retain];
-    o_vol_sld_img = [[NSImage imageNamed:@"fs_volume_slider_bar"] retain];
-    o_vol_mute_img = [[NSImage imageNamed:@"fs_volume_mute_highlight"] retain];
-    o_vol_max_img = [[NSImage imageNamed:@"fs_volume_max_highlight"] retain];
-    o_time_sld_img = [[NSImage imageNamed:@"fs_time_slider"] retain];
+    o_background_img = [imageFromRes(@"fs_background") retain];
+    o_vol_sld_img = [imageFromRes(@"fs_volume_slider_bar") retain];
+    o_vol_mute_img = [imageFromRes(@"fs_volume_mute_highlight") retain];
+    o_vol_max_img = [imageFromRes(@"fs_volume_max_highlight") retain];
+    o_time_sld_img = [imageFromRes(@"fs_time_slider") retain];
 
     return view;
 }
@@ -513,14 +517,14 @@
 
 - (void)setPlay
 {
-    [o_play setImage:[NSImage imageNamed:@"fs_play_highlight"]];
-    [o_play setAlternateImage: [NSImage imageNamed:@"fs_play"]];
+    [o_play setImage:imageFromRes(@"fs_play_highlight")];
+    [o_play setAlternateImage: imageFromRes(@"fs_play")];
 }
 
 - (void)setPause
 {
-    [o_play setImage: [NSImage imageNamed:@"fs_pause_highlight"]];
-    [o_play setAlternateImage: [NSImage imageNamed:@"fs_pause"]];
+    [o_play setImage: imageFromRes(@"fs_pause_highlight")];
+    [o_play setAlternateImage: imageFromRes(@"fs_pause")];
 }
 
 - (void)setStreamTitle:(NSString *)o_title
@@ -679,7 +683,7 @@
 - (void)drawKnobInRect:(NSRect)knobRect
 {
     NSRect image_rect;
-    NSImage *img = [NSImage imageNamed:@"fs_time_slider_knob_highlight"];
+    NSImage *img = imageFromRes(@"fs_time_slider_knob_highlight");
     image_rect.size = [img size];
     image_rect.origin.x = 0;
     image_rect.origin.y = 0;
@@ -723,7 +727,7 @@
 - (void)drawKnobInRect:(NSRect) knobRect
 {
     NSRect image_rect;
-    NSImage *img = [NSImage imageNamed:@"fs_volume_slider_knob_highlight"];
+    NSImage *img = imageFromRes(@"fs_volume_slider_knob_highlight");
     image_rect.size = [img size];
     image_rect.origin.x = 0;
     image_rect.origin.y = 0;
