@@ -2,7 +2,7 @@
  * vlm.cpp : VLM Management
  ****************************************************************************
  * Copyright © 2008 the VideoLAN team
- * $Id: bc7d96bd9ded351780feb9201915d6f90f8cae92 $
+ * $Id: 595f015af4fd6857420a0ab6fdc0c8872e45dcca $
  *
  * Authors: Jean-Baptiste Kempf <jb@videolan.org>
  *          Jean-François Massol <jf.massol -at- gmail.com>
@@ -23,10 +23,6 @@
  * Foundation, Inc., 51 Franklin street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
-
 #include "dialogs/vlm.hpp"
 
 #ifdef ENABLE_VLM
@@ -54,7 +50,7 @@
 #include <QFileDialog>
 
 
-VLMDialog::VLMDialog( intf_thread_t *_p_intf ) : QVLCDialog( (QWidget*)_p_intf->p_sys->p_mi, _p_intf )
+VLMDialog::VLMDialog( intf_thread_t *_p_intf ) : QVLCFrame( _p_intf )
 {
     p_vlm = vlm_New( p_intf );
 
@@ -290,7 +286,7 @@ void VLMDialog::mediasPopulator()
         int i_nMedias;
         QString typeShortName;
         int vlmItemCount;
-        vlm_media_t ***ppp_dsc = (vlm_media_t ***)malloc( sizeof( vlm_media_t ) );
+        vlm_media_t ***ppp_dsc = (vlm_media_t ***)malloc( sizeof( vlm_media_t** ) );
 
         /* Get medias information and numbers */
         vlm_Control( p_vlm, VLM_GET_MEDIAS, ppp_dsc, &i_nMedias );
@@ -901,7 +897,7 @@ void VLMDialog::toggleVisible()
 
     ui.vlmListItem->clear();
     mediasPopulator();
-    QVLCDialog::toggleVisible();
+    QVLCFrame::toggleVisible();
 }
 
 
